.. _spkg_sqlite:

sqlite: An SQL database engine
========================================

Description
-----------

SQLite is a software library that implements a self-contained,
serverless, zero-configuration, transactional SQL database engine.

License
-------

Public Domain


Upstream contact
----------------

-  https://www.sqlite.org

Dependencies
------------

-  readline


Special Update/Build Instructions
---------------------------------

-  Use the autoconf version of sqlite.

Type
----

standard


Dependencies
------------

- :ref:`spkg_readline`

Version Information
-------------------

package-version.txt::

    3.36.0


Equivalent System Packages
--------------------------

.. tab:: Alpine

   .. CODE-BLOCK:: bash

       $ apk add sqlite-dev 


.. tab:: Arch Linux

   .. CODE-BLOCK:: bash

       $ sudo pacman -S sqlite3 


.. tab:: conda-forge

   .. CODE-BLOCK:: bash

       $ conda install sqlite 


.. tab:: Debian/Ubuntu

   .. CODE-BLOCK:: bash

       $ sudo apt-get install libsqlite3-dev sqlite3 


.. tab:: Fedora/Redhat/CentOS

   .. CODE-BLOCK:: bash

       $ sudo yum install sqlite-devel sqlite 


.. tab:: FreeBSD

   .. CODE-BLOCK:: bash

       $ sudo pkg install databases/sqlite3 


.. tab:: Gentoo Linux

   .. CODE-BLOCK:: bash

       $ sudo emerge dev-db/sqlite 


.. tab:: Homebrew

   .. CODE-BLOCK:: bash

       $ brew install sqlite 


.. tab:: MacPorts

   .. CODE-BLOCK:: bash

       $ sudo port install sqlite3 


.. tab:: Nixpkgs

   .. CODE-BLOCK:: bash

       $ nix-env --install sqlite 


.. tab:: openSUSE

   .. CODE-BLOCK:: bash

       $ sudo zypper install pkgconfig\(sqlite3\) 


.. tab:: Slackware

   .. CODE-BLOCK:: bash

       $ sudo slackpkg install sqlite icu4c 


.. tab:: Void Linux

   .. CODE-BLOCK:: bash

       $ sudo xbps-install sqlite-devel 



See https://repology.org/project/sqlite/versions

If the system package is installed, ``./configure`` will check if it can be used.

